##  Deleting Transformation Items
To delete a Transformation item, follow the instructions below:
  1. Navigate to the Transformation tab in the Fact Sheet.
  2. Hover over the name of the Transformation you want to delete, and you will see the three-dot menu icon appear in the right corner.
  3. Click on the three-dot menu icon and select Delete.
![Deleting Transformations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757f52a7a4410149da1a441c67e03c6_LowRes.png)
Deleting Transformations
